import React from 'react';
import PropTypes from 'prop-types';
import { FormattedMessage } from 'react-intl';
import { RouteLink } from '../../route-link/route-link';

export const AlertLinks = ({
  errorMessageId, errorLinks, onClick, locale,
}) => {
  const values = errorLinks.reduce((acc, link) => {
    acc[link.id] = (
      <RouteLink
        onClick={onClick}
        locale={locale}
        to={link.href}
      >
        <FormattedMessage id={link.messageId} />
      </RouteLink>
    );
    return acc;
  }, {});

  return <FormattedMessage id={errorMessageId} values={values} />;
};

AlertLinks.propTypes = {
  errorMessageId: PropTypes.string.isRequired,
  errorLinks: PropTypes.arrayOf(PropTypes.shape({
    id: PropTypes.string.isRequired,
    href: PropTypes.string.isRequired,
    messageId: PropTypes.string.isRequired,
  })).isRequired,
  locale: PropTypes.string.isRequired,
  onClick: PropTypes.func,
};

AlertLinks.defaultProps = {
  onClick: null,
};
