import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { replace, pathOr } from 'ramda';
import { intlShape, injectIntl } from 'react-intl';
import Alert from 'reactstrap/lib/Alert';
import Button from 'reactstrap/lib/Button';
import Container from 'reactstrap/lib/Container';
import { IconAttention } from '../../icons/icon-attention/icon-attention';
import { UNDEFINED_ERROR_ID } from '../../../constants';
import './global-alert.scss';

export const parseAndAddRefreshLink = replace(/\[(.+?)\]/, '<a href="#" onclick="window.location.reload(true); return false;">$1</a>');
const createMarkup = html => ({ __html: html });

export class GlobalAlertUI extends Component {
  static propTypes = {
    intl: intlShape.isRequired,
    children: PropTypes.node,
    onDismiss: PropTypes.func,
  };

  static defaultProps = {
    children: null,
    onDismiss: null,
  };

  state = {
    visible: true,
  };

  errorMessageWithRefreshLink = errorMessageId =>
    parseAndAddRefreshLink(this.props.intl.formatMessage({ id: errorMessageId }));

  onDismiss = () => {
    const { onDismiss } = this.props;
    this.setState({ visible: false });
    if (onDismiss) {
      onDismiss();
    }
  };

  render() {
    const { children } = this.props;

    return (
      <Container className="global-alert position-fixed pt-0_5">
        <Alert color="red-r30" isOpen={this.state.visible}>
          <div className="d-flex justify-content-center alert-text pr-4 pr-sm-0">
            <div className="alert-attention">
              <IconAttention />
            </div>
            <span
              dangerouslySetInnerHTML={
                createMarkup(this.errorMessageWithRefreshLink(pathOr(UNDEFINED_ERROR_ID, ['props', 'errorMessageId'], children)))
              }
            />
          </div>
          <Button color="link" className="alert-dismiss" onClick={this.onDismiss}>&times;</Button>
        </Alert>
      </Container>
    );
  }
}

export const GlobalAlert = injectIntl(GlobalAlertUI);
