import Button from 'reactstrap/lib/Button';
import { GlobalAlert } from './global-alert';
import { AlertGeneral } from '../alert-general/alert-general';

let wrapper;
const onDismiss = jest.fn();

describe('<GlobalAlert />', () => {
  beforeEach(() => {
    wrapper = shallow(<GlobalAlert onDismiss={onDismiss} />).dive();
    onDismiss.mockReset();
  });

  test('should match snapshot', () => {
    expect(wrapper).toMatchSnapshot();
  });

  describe('when clicking dismiss', () => {
    test('should dismiss alert', () => {
      expect(wrapper.state().visible).toBe(true);
      wrapper.find(Button).simulate('click');
      expect(wrapper.state().visible).toBe(false);
      expect(onDismiss).toHaveBeenCalledTimes(1);
    });
  });

  describe('with children', () => {
    test('should match snapshot', () => {
      expect(shallow(<GlobalAlert>Test message</GlobalAlert>).dive()).toMatchSnapshot();
    });
  });

  describe('with children errorMessageId', () => {
    test('should match snapshot', () => {
      expect(shallow(<GlobalAlert><AlertGeneral errorMessageId="some-custom-error-id" /></GlobalAlert>).dive()).toMatchSnapshot();
    });
  });

  describe('w/o onDismiss', () => {
    test('should match snapshot', () => {
      wrapper = shallow(<GlobalAlert />).dive();
      wrapper.find(Button).simulate('click');
      expect(onDismiss).not.toHaveBeenCalled();
    });
  });
});
