import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { GlobalAlert } from '../alerts/global-alert/global-alert';

export class ErrorBoundary extends Component {
  static propTypes = {
    message: PropTypes.oneOfType([
      PropTypes.string,
      PropTypes.node,
    ]),
    onDismissAlert: PropTypes.func,
    children: PropTypes.node.isRequired,
  };

  static defaultProps = {
    message: null,
    onDismissAlert: null,
  };

  state = {
    hasError: false,
  };

  componentDidCatch(error, info) {
    this.setState({ hasError: true });
    console.info(error, info);
  }

  render() {
    const { message, children, onDismissAlert } = this.props;
    if (this.state.hasError) {
      return message ?
        <GlobalAlert onDismiss={onDismissAlert}>
          {message}
        </GlobalAlert> :
        <GlobalAlert onDismiss={onDismissAlert} />;
    }
    return children;
  }
}
