import React from 'react';
import { ErrorBoundary } from './error-boundary';

describe('<ErrorBoundary />', () => {
  describe('when everything goes fine', () => {
    test('should render children', () => {
      const wrapper = mount((
        <ErrorBoundary>
          <div>
            <span>Some node</span>
          </div>
        </ErrorBoundary>
      ));
      expect(wrapper).toMatchSnapshot();
    });
  });

  describe('when error is thrown', () => {
    test('should render excuse message', () => {
      console.error = jest.fn();
      console.info = jest.fn();
      const ErrorComponent = () => {
        const testObject = {};
        return <span>Some node {testObject.nonExist.some}</span>;
      };

      const wrapper = mount((
        <ErrorBoundary message="Excuse me, error thrown">
          <div>
            <ErrorComponent />
          </div>
        </ErrorBoundary>
      ));
      expect(wrapper).toMatchSnapshot();
    });

    describe('and no message', () => {
      test('should render with default message', () => {
        console.error = jest.fn();
        console.info = jest.fn();
        const ErrorComponent = () => {
          const testObject = {};
          return <span>Some node {testObject.nonExist.some}</span>;
        };

        const wrapper = mount((
          <ErrorBoundary>
            <div>
              <ErrorComponent />
            </div>
          </ErrorBoundary>
        ));
        expect(wrapper).toMatchSnapshot();
      });
    });
  });
});
