import React from 'react';
import PropTypes from 'prop-types';
import classNames from 'classnames';
import Container from 'reactstrap/lib/Container';
import Navbar from 'reactstrap/lib/Navbar';
import NavbarBrand from 'reactstrap/lib/NavbarBrand';
import Nav from 'reactstrap/lib/Nav';
import { IconLogoFooter } from '../icons/icon-logo-footer/icon-logo-footer';
import { LangSwitcher } from '../lang-switcher/lang-switcher';
import './footer.scss';

export const Footer = ({
  locale, locales, children, className,
}) => (
  <footer className={classNames('footer p-0 border-top pt-6 bg-white w-100', className)}>
    <Container>
      <Navbar>
        <NavbarBrand href={`/${locale}/`}>
          <IconLogoFooter />
        </NavbarBrand>
        <Nav>
          {children}
          <LangSwitcher locale={locale} locales={locales} />
        </Nav>
      </Navbar>
    </Container>
  </footer>
);

Footer.propTypes = {
  children: PropTypes.node.isRequired,
  locale: PropTypes.string.isRequired,
  className: PropTypes.string,
  locales: PropTypes.oneOfType([PropTypes.objectOf(PropTypes.string), PropTypes.arrayOf(PropTypes.string)]),
};

Footer.defaultProps = {
  className: '',
  locales: undefined,
};
