import PropTypes from 'prop-types';
import { F } from 'ramda';
import React from 'react';
import Input from 'reactstrap/lib/Input';
import FormFeedback from 'reactstrap/lib/FormFeedback';
import { FormattedMessage } from 'react-intl';
import { IconLoading } from '../../icons/icon-loading/icon-loading';
import { IconSaved } from '../../icons/icon-saved/icon-saved';
import './input-validation.scss';

export function InputValidation({
  addValid,
  isValidCb,
  errorMessage,
  loading,
  saved,
  ...props
}) {
  const isValid = isValidCb();
  const isErrorMessageShown = addValid && !isValid;
  const addValidProp = addValid ? {
    valid: isValid,
    invalid: !isValid,
  } : {};

  return (
    <div className="text-right input-container">
      <Input {...props} {...addValidProp} />
      {loading && <IconLoading className="loading-icon" />}
      {saved && <IconSaved className="saved-icon" />}
      {isErrorMessageShown && (
        <FormFeedback>
          <FormattedMessage id={errorMessage} />
        </FormFeedback>
      )}
    </div>
  );
}

InputValidation.propTypes = {
  addValid: PropTypes.bool,
  isValidCb: PropTypes.func,
  errorMessage: PropTypes.string,
  loading: PropTypes.bool,
  saved: PropTypes.bool,
};

InputValidation.defaultProps = {
  addValid: true,
  isValidCb: F,
  errorMessage: '', // TODO: Add some key to react-intl for default error message
  loading: false,
  saved: false,
};
