import React, { Component } from 'react';
import PropTypes from 'prop-types';
import classNames from 'classnames';
import Input from 'reactstrap/lib/Input';
import Label from 'reactstrap/lib/Label';
import Button from 'reactstrap/lib/Button';
import { FormattedMessage } from 'react-intl';
import './input-with-icon-btn.scss';

export class InputWithIconBtn extends Component {
  static propTypes = {
    icon: PropTypes.node.isRequired,
    buttonText: PropTypes.string.isRequired,
    disabled: PropTypes.bool,
    label: PropTypes.string,
    value: PropTypes.string,
    setValue: PropTypes.func,
    className: PropTypes.string,
    onClick: PropTypes.func,
  };

  static defaultProps = {
    value: '',
    label: '',
    className: '',
    onClick: null,
    setValue: null,
    disabled: false,
  };

  onChange = (e) => {
    const { setValue } = this.props;
    if (setValue) {
      setValue(e.target.value);
    }
  };

  render() {
    const {
      label,
      className,
      buttonText,
      value,
      disabled,
    } = this.props;
    return (
      <div className={classNames(className, 'input-with-icon-btn d-flex flex-row')}>
        <span className="icon-wrapper align-self-end">
          {this.props.icon}
        </span>
        <div className="input-wrapper w-100">
          {label && <Label className="text-small text-gray-dark-hint mb-0_5"><FormattedMessage id={label} /></Label>}
          <div className="d-flex btn-input-wrapper">
            {disabled && <Input disabled className="rounded-0" value={value} />}
            {!disabled && <Input className="change-value rounded-0" onChange={this.onChange} />}
            <Button outline color="secondary" size="xs" onClick={this.props.onClick}>
              <FormattedMessage id={buttonText} />
            </Button>
          </div>
        </div>
      </div>
    );
  }
}
