import React, { Component } from 'react';
import PropTypes from 'prop-types';
import classNames from 'classnames';
import { InputValidation } from '../input-validation/input-validation';
import { PIN_CODE_LENGTH } from '../../../helpers/pin-code';

export class PincodeInput extends Component {
  static propTypes = {
    className: PropTypes.string,
    value: PropTypes.string,
    setPinCode: PropTypes.func.isRequired,
    inputError: PropTypes.string,
  };

  static defaultProps = {
    className: '',
    value: '',
    inputError: null,
  };

  setPinCode = (event) => {
    const { value } = event.target;
    this.props.setPinCode(value);
  };

  render() {
    const {
      className,
      value,
      inputError,
      setPinCode,
      ...props
    } = this.props;

    return (<InputValidation
      className={classNames(className, 'text-center pin-code')}
      maxLength={PIN_CODE_LENGTH}
      type="password"
      placeholder="&#8226;&#8226;&#8226;&#8226;&#8226;&#8226;&#8226;&#8226;"
      onChange={this.setPinCode}
      addValid={!!inputError}
      errorMessage={inputError}
      value={value}
      {...props}
    />);
  }
}
