import React, { Component } from 'react';
import PropTypes from 'prop-types';
import Dropdown from 'reactstrap/lib/Dropdown';
import DropdownToggle from 'reactstrap/lib/DropdownToggle';
import DropdownMenu from 'reactstrap/lib/DropdownMenu';
import DropdownItem from 'reactstrap/lib/DropdownItem';
import { LANG_NAMES } from '../../constants';
import { IconArrowDown } from '../icons/icon-arrow-down/icon-arrow-down';
import { changeLocation } from '../../helpers/change-location';
import './lang-switcher.scss';

export class LangSwitcher extends Component {
  static propTypes = {
    locale: PropTypes.string.isRequired,
    locales: PropTypes.oneOfType([PropTypes.objectOf(PropTypes.string), PropTypes.arrayOf(PropTypes.string)]),
  };

  static defaultProps = {
    locales: Object.keys(LANG_NAMES),
  };

  state = {
    dropdownOpen: false,
  };

  isMultiDomains = !Array.isArray(this.props.locales);

  toggle = () => {
    this.setState(prevState => ({
      dropdownOpen: !prevState.dropdownOpen,
    }));
  }

  changeLocale = (e) => {
    const { locale, locales } = this.props;
    const newLocale = e.target.value;

    if (newLocale !== locale) {
      const url = this.isMultiDomains ?
        window.location.origin.replace(process.env.DOMAIN.toLowerCase(), locales[newLocale] || 'com') :
        `${window.location.origin}${window.location.pathname.replace(locale, newLocale)}`;

      changeLocation(url);
    }
  }

  render() {
    const { dropdownOpen } = this.state;
    const { locale, locales } = this.props;
    const localesList = this.isMultiDomains ? Object.keys(locales) : locales;

    return (
      <Dropdown isOpen={dropdownOpen} toggle={this.toggle} className="lang-switcher">
        <DropdownToggle nav className="p-0 pl-3_5 text-gray-dark-secondary">
          {LANG_NAMES[locale]} <IconArrowDown />
        </DropdownToggle>

        <DropdownMenu className="language-dropdown">
          {
            localesList.map(loc => (
              <DropdownItem key={loc} value={loc} active={loc === locale} onClick={this.changeLocale}>
                {LANG_NAMES[loc]}
              </DropdownItem>
            ))
          }
        </DropdownMenu>
      </Dropdown>
    );
  }
}
