import React from 'react';
import { LangSwitcher } from './lang-switcher';
import { changeLocation } from '../../helpers/change-location';

jest.mock('../../helpers/change-location');
process.env.DOMAIN = 'com';

describe('<LangSwitcher />', () => {
  const wrapper = shallow(<LangSwitcher locale="en-us" />);

  test('when no locales from props should match snapshot', () => {
    expect(wrapper).toMatchSnapshot();
  });

  describe('when locales is Array', () => {
    expect(shallow(<LangSwitcher locale="en-us" locales={['en-us', 'ru-ru', 'es-es']} />)).toMatchSnapshot();
  });

  describe('when locales is Object', () => {
    expect(shallow(<LangSwitcher locale="en-us" locales={{ 'en-us': 'com', 'ru-ru': 'net', 'es-es': 'es' }} />)).toMatchSnapshot();
  });

  test('should toggle dropdown', () => {
    wrapper.instance().toggle();
    expect(wrapper.instance().state.dropdownOpen).toBe(true);
  });

  test('should not change location when locale equals new locale', () => {
    const event = {
      target: {
        value: 'en-us',
      },
    };
    wrapper.instance().changeLocale(event);
    expect(changeLocation).not.toHaveBeenCalled();
  });

  test('should change location when locale not equal new locale', () => {
    const event = {
      target: {
        value: 'ru-ru',
      },
    };
    wrapper.instance().changeLocale(event);

    expect(changeLocation).toHaveBeenCalled();
  });
});
