import React from 'react';
import { ModalWindowUI } from './modal-window';

const TEST_MODAL_ID = 'TEST_MODAL_ID';
const openModalMock = jest.fn();
const closeModalMock = jest.fn();
const onOpened = jest.fn();

describe('<ModalWindowUI />', () => {
  let wrapper;

  beforeAll(() => {
    wrapper = shallow((
      <ModalWindowUI
        openModal={openModalMock}
        closeModal={closeModalMock}
        id={TEST_MODAL_ID}
      >
        Modal content goes here
      </ModalWindowUI>
    ));
  });

  beforeEach(() => {
    openModalMock.mockReset();
    closeModalMock.mockReset();
  });

  describe('when window is not rendered isOpen', () => {
    test('should render it closed', () => {
      expect(wrapper).toMatchSnapshot();
    });

    test('should open modal triggering toggle', () => {
      wrapper.instance().toggle();
      expect(openModalMock).toHaveBeenCalledTimes(1);
      expect(closeModalMock).not.toHaveBeenCalled();
    });
  });

  describe('when window is opened', () => {
    beforeAll(() => {
      wrapper = shallow((
        <ModalWindowUI
          openModal={openModalMock}
          closeModal={closeModalMock}
          id={TEST_MODAL_ID}
          onOpened={onOpened}
          isOpen
        >
          Modal content goes here
        </ModalWindowUI>
      ));
    });

    test('should match snapshot', () => {
      expect(wrapper).toMatchSnapshot();
    });

    test('should close modal triggering toggle', () => {
      wrapper.instance().toggle();
      expect(openModalMock).not.toHaveBeenCalled();
      expect(closeModalMock).toHaveBeenCalledTimes(1);
    });

    test('should call onOpened', () => {
      wrapper.instance().onOpened();
      expect(onOpened).toHaveBeenCalledTimes(1);
    });

    describe('when onOpened is not passed via props', () => {
      beforeEach(() => {
        onOpened.mockReset();
      });

      test('should not call prop onOpened', () => {
        wrapper = shallow((
          <ModalWindowUI
            openModal={openModalMock}
            closeModal={closeModalMock}
            id={TEST_MODAL_ID}
          >
            Modal content goes here
          </ModalWindowUI>
        ));
        wrapper.instance().onOpened();
        expect(onOpened).not.toHaveBeenCalled();
      });
    });
  });

  describe('when window is not centered', () => {
    beforeAll(() => {
      wrapper = shallow((
        <ModalWindowUI
          openModal={openModalMock}
          closeModal={closeModalMock}
          id={TEST_MODAL_ID}
          isCentered={false}
        >
          Modal content goes here
        </ModalWindowUI>
      ));
    });

    test('should match snapshot', () => {
      expect(wrapper).toMatchSnapshot();
    });
  });
});
