import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { values } from 'ramda';
import { FormattedMessage } from 'react-intl';
import Dropdown from 'reactstrap/lib/Dropdown';
import DropdownMenu from 'reactstrap/lib/DropdownMenu';
import DropdownItem from 'reactstrap/lib/DropdownItem';
import DropdownToggle from 'reactstrap/lib/DropdownToggle';
import { IconArrowDown } from '../icons/icon-arrow-down/icon-arrow-down';
import { Avatar } from '../avatar/avatar';
import './profile-menu.scss';

export const MENU_ITEM_TYPES = {
  LINK: 'LINK',
  DIVIDER: 'DIVIDER',
};

const MIN_WIDTH_DROPDOWN = 216;

const linkTagPropTypes = PropTypes.oneOfType([
  PropTypes.string,
  PropTypes.func,
]);

export class ProfileMenu extends Component {
  static propTypes = {
    isUserLoggedIn: PropTypes.bool.isRequired,
    className: PropTypes.string,
    menuItems: PropTypes.arrayOf(PropTypes.shape({
      linkTag: linkTagPropTypes,
      link: PropTypes.string,
      classname: PropTypes.string,
      message: PropTypes.string,
      type: PropTypes.oneOf(values(MENU_ITEM_TYPES)).isRequired,
    })).isRequired,
    // Tag (Component or container component we use to render a menu link)
    linkTag: linkTagPropTypes.isRequired,
    userPhotoUrl: PropTypes.string,
  };

  static defaultProps = {
    className: '',
    userPhotoUrl: '',
  }

  state = {
    menuOpen: false,
  }

  toggleMenu = () => {
    this.setState(previousState => ({
      menuOpen: !previousState.menuOpen,
    }));
  }

  renderCategories = () => (
    this.props.menuItems.map(({
      type, link = '', classname = null, message = '', linkTag,
    }, i) => {
      const key = `${type}${i}`;
      return ({
        [MENU_ITEM_TYPES.LINK]: (
          <DropdownItem
            key={key}
            tag={linkTag || this.props.linkTag}
            to={link}
            className={classname}
          >
            <FormattedMessage id={message} />
          </DropdownItem>
        ),
        [MENU_ITEM_TYPES.DIVIDER]: (
          <DropdownItem
            key={key}
            divider
          />
        ),
      }[type]);
    })
  );

  render() {
    const { menuOpen } = this.state;
    const { isUserLoggedIn, className, userPhotoUrl } = this.props;

    if (!isUserLoggedIn) {
      return null;
    }

    return (
      <Dropdown isOpen={menuOpen} toggle={this.toggleMenu} className={className}>
        <DropdownToggle nav className="px-0">
          <div className="profile-menu d-flex">
            <Avatar url={userPhotoUrl} length="28" className="mr-0_5" />
            <span className="d-flex align-items-center">
              <IconArrowDown />
            </span>
          </div>
        </DropdownToggle>
        <DropdownMenu right style={{ minWidth: `${MIN_WIDTH_DROPDOWN}px` }}>
          {this.renderCategories()}
        </DropdownMenu>
      </Dropdown>
    );
  }
}
