import React from 'react';
import Button from 'reactstrap/lib/Button';
import { ProfileMenu, MENU_ITEM_TYPES } from './profile-menu';

describe('<ProfileMenu />', () => {
  let wrapper;
  const menuItems = [
    {
      type: MENU_ITEM_TYPES.LINK,
      link: '/profile/',
      message: 'menu.profile.text',
      linkTag: (Button),
    },
    {
      type: MENU_ITEM_TYPES.DIVIDER,
    },
    {
      type: MENU_ITEM_TYPES.LINK,
      link: '/post/create',
      message: 'menu.new-post.text',
      classname: 'text-primary',
    },
  ];

  beforeAll(() => {
    wrapper = shallow(<ProfileMenu linkTag={Button} isUserLoggedIn menuItems={menuItems} />);
  });

  describe('when user is not logged in', () => {
    test('should be empty', () => {
      wrapper.setProps({
        isUserLoggedIn: false,
      });
      expect(wrapper).toMatchSnapshot();
    });
  });

  describe('when user is logged in', () => {
    test('should match snapshot', () => {
      wrapper.setProps({
        isUserLoggedIn: true,
      });
      expect(wrapper).toMatchSnapshot();
    });

    test('should toggle dropdown menu', () => {
      wrapper.instance().toggleMenu();
      expect(wrapper.state().menuOpen).toBe(true);
    });
  });

  describe('when the user is has his photo set', () => {
    test('should match the snapshot', () => {
      wrapper.setProps({
        userPhotoUrl: 'http://localhost/test-user/photo',
      });
      expect(wrapper).toMatchSnapshot();
    });
  });
});
