import React from 'react';
import PropTypes from 'prop-types';
import { Link } from 'react-router-dom';
import { wrapRoute2Locale } from '../../helpers/localization';

export const RouteLink = ({
  to, href, locale, className, children, onClick, style,
}) => {
  const withLocale = wrapRoute2Locale(to, locale);
  return (
    <Link href={href || withLocale} to={withLocale} className={className} onClick={onClick} style={style}>
      {children}
    </Link>
  );
};

RouteLink.propTypes = {
  to: PropTypes.string.isRequired,
  locale: PropTypes.string.isRequired,
  children: PropTypes.node.isRequired,
  className: PropTypes.string,
  href: PropTypes.string,
  onClick: PropTypes.func,
  style: PropTypes.objectOf(PropTypes.string),
};

RouteLink.defaultProps = {
  className: '',
  href: null,
  onClick: null,
  style: null,
};
