import React, { Component } from 'react';
import NavItem from 'reactstrap/lib/NavItem';
import NavLink from 'reactstrap/lib/NavLink';
import PropTypes from 'prop-types';
import classnames from 'classnames';
import { FormattedMessage } from 'react-intl';

export class TabLabel extends Component {
  static propTypes = {
    tabId: PropTypes.oneOfType([
      PropTypes.string,
      PropTypes.number,
    ]).isRequired,
    label: PropTypes.string.isRequired,
    onClick: PropTypes.func.isRequired,
    isActive: PropTypes.bool,
    className: PropTypes.string,
  };

  static defaultProps = {
    isActive: false,
    className: null,
  };

  toggle = () => {
    const { onClick, isActive, tabId } = this.props;

    if (!isActive) {
      onClick(tabId);
    }
  }

  render() {
    const { label, isActive, className } = this.props;

    return (
      <NavItem className={className}>
        <NavLink
          className={classnames({ active: isActive })}
          onClick={this.toggle}
        >
          <FormattedMessage id={label} />
        </NavLink>
      </NavItem>
    );
  }
}
