import React from 'react';
import { TabLabel } from './tab-label';

const onLabelClick = jest.fn();

describe('<TabLabel />', () => {
  beforeEach(() => {
    onLabelClick.mockReset();
  });

  describe('when label is not active', () => {
    const wrapper = shallow(<TabLabel label="recieve" tabId={0} onClick={onLabelClick} />);

    test('should match snapshot', () => {
      expect(wrapper).toMatchSnapshot();
    });

    test('should select tab triggering toggle', () => {
      wrapper.instance().toggle();
      expect(onLabelClick).toHaveBeenCalledTimes(1);
    });

    test('on NavLink click should trigger onClick with correct tabId', () => {
      wrapper.find('NavLink').simulate('click');
      expect(onLabelClick).toHaveBeenCalledWith(0);
    });
  });

  describe('when label is active', () => {
    const wrapper = shallow(<TabLabel label="recieve" tabId={0} isActive onClick={onLabelClick} />);

    test('should match snapshot', () => {
      expect(wrapper).toMatchSnapshot();
    });

    test('should not select tab triggering toggle', () => {
      wrapper.instance().toggle();
      expect(onLabelClick).not.toHaveBeenCalled();
    });
  });
});
