import { values, map, zipObj, split, compose, head } from 'ramda';
import ALL_LOCALES from './locale-keys';

export const LOCALE_KEYS = ALL_LOCALES;

export const LOCALE = 'locale';

/**
 * [ 'en-us', 'de-de' ]
 */
export const LOCALES = values(LOCALE_KEYS);
export const DEFAULT_LOCALE = LOCALE_KEYS.EN_US;
/**
 * [ 'en', 'de' ]
 */
export const LANGS = map(compose(head, split('-')), LOCALES);
/**
 * {
 *    en-us: 'en',
 *    de-de: 'de',
 * }
 */
export const LANG_KEYS = zipObj(LOCALES, LANGS);
/**
 * {
 *    en: 'en-us',
 *    de: 'de-de',
 * }
 */
export const LANG_TO_LOCALE = zipObj(LANGS, LOCALES);
export const DEFAULT_LANG = LANG_KEYS[LOCALE_KEYS.EN_US];

export const LANG_NAMES = {
  'az-az': 'Azərbaycan dili', // Azerbaijani
  'id-id': 'Bahasa Indonesia', // Indonesian
  'ms-my': 'Bahasa Melayu', // Malay
  'da-dk': 'Dansk', // Danish
  'de-de': 'Deutsch', // German
  'en-us': 'English', // English
  'es-es': 'Español', // Spanish
  'el-gr': 'Ελληνικά', // Greek
  'en-ph': 'Filipino', // Phillipino
  'fr-fr': 'Français', // French
  'it-it': 'Italiano', // Italian
  'nl-nl': 'Nederlands', // Dutch
  'pl-pl': 'Polski', // Polish
  'pt-pt': 'Português', // Portuguese
  'ro-ro': 'Română', // Romanian
  'fi-fi': 'Suomi', // Finnish
  'vi-vn': 'Tiếng Việt', // Vietnamese
  'tr-tr': 'Türkçe', // Turkish
  'be-by': 'Беларуская', // Belarusian
  'ru-ru': 'Русский', // Russian
  'uk-ua': 'Українська', // Ukrainian
  'zh-cn': '中文', // Chinese
  'ko-kr': '한국어', // Korean
  'ar-eg': 'العربية', // Arabic
  'hi-in': 'हिन्दी', // Hindi
  'fa-ir': 'فارسی', // Persian
  'he-il': 'עברית', // Hebrew
};

export const AVAILABLE_LOCALES = [
  'en-us',
  'ru-ru',
  'zh-cn',
  'es-es',
  'ko-kr',
  'ar-eg',
];

export const LOCALES_DOMAIN_MAPPING = {
  'en-us': 'com',
  'ru-ru': 'me',
  'zh-cn': 'net',
  'es-es': 'es',
  'ko-kr': 'kr',
  'ar-eg': 'pro',
};

export const CURRENCY_USD = 'USD';
export const CURRENCY_EUR = 'EUR';
export const ALL_CURRENCY = [CURRENCY_USD, CURRENCY_EUR];
export const DEFAULT_CURRENCY = CURRENCY_USD;

export const DEFAULT_RESET_STATE_TIMEOUT = 3000;

export const USERNAME_LENGTH_MAX = 16;
export const MEMO_LENGTH_MAX = 500;

export const MIN_FRACTION_DIGITS = 3;
export const MAX_FRACTION_DIGITS = 9;

// Errors, alerts
export const UNDEFINED_ERROR_ID = 'general.error.unknown';
export const SIGN_UP_ERROR_UNKNOWN = 'general.sign-up.error.unknown';
