import { compose, toString } from 'ramda';
import sha256 from 'crypto-js/sha256';

export const PIN_CODE_LENGTH = 8;

export const ERROR_CODES = {
  INCORRECT_LENGTH: 'wallet.sign-in.create-pin.error.length',
  PINS_DONT_MATCH: 'wallet.sign-in.create-pin.error.not-match',
  PIN_CODE_INCORRECT: 'wallet.sign-in.error',
};

/**
 * Check if pincode is valid entirely
 * @param {string} pin
 */
export const isPinValid = pin => /^[0-9]{8}$/.test(pin);

/**
 * Check if pincode entered symbols are valid
 * @param {string} pin
 */
export const isPinSymbolsValid = pin => /^[0-9]*$/.test(pin);

/**
 * @param {string} pinCode
 * @returns {string} - encoded pin code
 */
export const encryptPinCode = compose(toString, sha256);
